#!/bin/sh
. $HOME/.profile
# ----------------------------------------------------------------
# Name of this Script: driver.sh
# Purpose: This script copies the tar file from the NCO /common/..
# and extract the contents (gif files) to the appropriate $cycle
# directory.
#
# Environment Variables to be passed as arguments to the driver script:
# PROD_DATE:  yyyymmdd
# MODEL:  { gfs | gdas | gefs}
# CPCI_IN:  /common/data/model/com/cpci/para/cpci.${PROD_DATE}/${MODEL}
# CPCI_RZDM: /cpc/rzdm/www/cpc/htdocs/products/international/cpci/data
# CPCI_HOME:  $CPCI_HOME
# CYCLE:       { 00 | 06 | 12 | 18 }
# INPUT_TARFILE: cpci.${PROD_DATE}_${MODEL}_${CYCLE}.tar
#
# Command Line Example:
# ./driver.sh $MODEL $CYCLE $CPCI_HOME $CPCI_IN
# ./driver.sh gfs 12 $CPCI_HOME/data /common/data/model/com/cpci/para/cpci.20150901
#
# Development:
# Contact Name: Vadlamani Kumar
# Contact Phone: 301-683-3462
# Contact Email: vadlamani.kumar@noaa.gov
#
# Operations:
# Contact Names Vadlamani Kumar / Muthuvale Chellaiah
# Contact Phone: 301-682-3462
# Contact email: vadlamani.kumar@gmail.com  
# ----------------------------------------------------------------
# 18z cycle GFS is available after mid-night so the date changes
#
# cp /common/data/model/com/cpci/para/cpci.${today}/${model}/cpci.${today}_${model}_${cycle}.tar .
#
#
start_time=`date`
# Begin Process
#
echo "*** Process has begun at $start_time***"
#
MODEL=$1
CYCLE=$2
#
# CPCI_HOME and CPCI_IN   ... defined in .bashrc
#
echo $model $CYCLE $CPCI_HOME $CPCI_IN
#
if [[ "$CYCLE" = "18" ]] ; then
  PROD_DATE=`date --date "1 day ago" "+%Y%m%d"`
  PROD_DATE_OLD=`date --date "2 day ago" "+%Y%m%d"`
else
  PROD_DATE=`date --date "0 day ago" "+%Y%m%d"`
  PROD_DATE_OLD=`date --date "1 day ago" "+%Y%m%d"`
fi
#
#
echo $model $CYCLE $CPCI_HOME $CPCI_IN
#
cd $CPCI_RZDM
#
if [[ "$MODEL" = "gfs" ]] || [[ "$MODEL" = "gfs" ]] || [[ "$MODEL" = "gfs" ]] ; then
  cd $CPCI_RZDM
fi
#
if [[ "$MODEL" = "gefs_boxw" ]] ; then
  cd $CPCI_RZDM/$MODEL
fi
#
if [[ "$MODEL" = "gfs_skewt" ]] ; then
  cd $CPCI_RZDM/$MODEL
fi
#
#
TARFILE=cpci.${PROD_DATE}_${MODEL}_${CYCLE}.tar
INPUT_TARFILE=$CPCI_IN/cpci.${PROD_DATE}/${MODEL}/${INPUT_TARFILE}/$TARFILE
TARFILE_OLD=cpci.${PROD_DATE_OLD}_${MODEL}_${CYCLE}.tar
#
#test for the presence and validity of the tar file and then copy
echo "Checking..."
if [ -f $INPUT_TARFILE ]
  then
    echo "input tar file"  $INPUT_TARFILE "exists"
    echo
    echo "removing the old tarfile " $TARFILE_OLD
    rm $CPCI_HOME/input_tar_files/$TARFILE_OLD
    echo
    echo "copying the input tarfile from /common.." $PROD_DATE_OLD
    echo
    cp ${INPUT_TARFILE} .
    echo
    echo "untaring the file " $TARFILE 
#    tar xvf ${TARFILE}
    tar --strip-components=9 -xf ${TARFILE}
    mv ${TARFILE} $CPCI_HOME/input_tar_files/
    echo
    end_time=`date`
    echo "Completed untaring the file ... process completed at $end_time "
    echo
    echo "Attempt1. Successfully completed processing $TARFILE " | mail -s "$TARFILE Processing Completed" vadlamani.kumar@noaa.gov
else
    echo "Attempt1. Tar file not found ...Trying again after 30 minutes for $TARFILE "
    sleep 1800
    if [ -f $INPUT_TARFILE ]
      then
        echo "input tar file"  $INPUT_TARFILE "exists"
        echo
        echo "removing the old tarfile " $TARFILE_OLD
        rm $CPCI_HOME/input_tar_files/$TARFILE_OLD
        echo
        echo "copying the input tarfile from /common.." $PROD_DATE_OLD
    	echo
        cp ${INPUT_TARFILE} .
        echo
        echo "untaring the file " $TARFILE
#        tar xvf ${TARFILE}
        tar --strip-components=9 -xf ${TARFILE}
        mv ${TARFILE} $CPCI_HOME/input_tar_files/
        echo
        end_time=`date`
        echo "Completed untaring the file ... process completed at $end_time "
        echo
        echo "Attempt2. Successfully completed processing $TARFILE " | mail -s "$TARFILE Processing Completed" vadlamani.kumar@noaa.gov
    else
        end_time=`date`
        echo "input tar file"  $INPUT_TARFILE "does not exist ... aborting the further processing at ... $end_time "
        echo
        echo "Aborted process at $end_time -- $INPUT_TARFILE does not exist" | mail -s "Process Failure due to non-existent $TARFILE" vadlamani.kumar@noaa.gov
        echo
    fi
fi
exit
